ValidationError

Enum ValidationError 

#[non_exhaustive]
pub enum ValidationError { InvalidPlayerNum, NonMatchingInfosetNames, NonMatchingInfosetActions, NullOutcomePayoffs, InvalidNumberOfPayoffs, NonMatchingOutcomeNames, NonMatchingOutcomePayoffs, UndefinedOutcome, UndeclaredInfoset, }
An error that results from something invalid about the parsed extensive form game

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidPlayerNum

A player’s number wasn’t between one and the number of players



NonMatchingInfosetNames

An infoset had different names attached to it



NonMatchingInfosetActions

An infoset had different sets of associated actions



NullOutcomePayoffs

A name or payoffs were attached to the null (0) outcome



InvalidNumberOfPayoffs

The number of specified payoffs did not match the number of players



NonMatchingOutcomeNames

An outcome was defined with a name that didn’t match its first definition



NonMatchingOutcomePayoffs

An outcome was defined with payoffs that didn’t match its first definition



UndefinedOutcome

A node referenced an outcome that was never defined



UndeclaredInfoset

A node omitted its action list for an infoset that was never declared