pub struct EscapedStr { /* private fields */ }Expand description
A string with backslash escapes in it
This wrapper allows referencing escaped strings in the source while preventing improper use. Use EscapedStr::as_raw_str to access the underlying buffer, or the Display trait to get owned versions. Use EscapedStr::unescape to access a char iter.
Implementations
Sourceimpl EscapedStr
impl EscapedStr