Player

Struct Player 

pub struct Player<'a, 'g> { /* private fields */ }
A player node in the game tree

A player node represents a place where one of the players chooses what happens next.

Implementations

Source

impl<'a, 'g> Player<'a, 'g>

pub fn name(self) -> &'a EscapedStr

The name of the node

pub fn player_num(self) -> usize

The player acting at this node

This will always be between 1 and the number of players.

pub fn infoset(self) -> u64

The infoset id for this node and player

pub fn infoset_name(self) -> &'a EscapedStr

The infoset’s label

pub fn actions( self, ) -> impl Iterator<Item = (&'a EscapedStr, Node<'a, 'g>)> + 'g

All the actions a player can take with their names and resulting nodes

pub fn action(self, label: &str) -> Option<Node<'a, 'g>>

The child reached by the action with the given label

label is matched against the unescaped form of each action’s label. Labels need not be unique within an infoset, so this returns the first match.

pub fn len(self) -> usize

The number of actions (always at least one)

pub fn action_at(self, index: usize) -> Option<(&'a EscapedStr, Node<'a, 'g>)>

The name and child for the action at the given index

pub fn outcome(self) -> u64

The outcome id

pub fn outcome_name(self) -> Option<&'a EscapedStr>

The name of the outcome

None for the null (0) outcome.

pub fn outcome_payoffs(self) -> Option<&'g [BigRational]>

Payoffs associated with the outcome

None only for the null (0) outcome.