pub struct Terminal<'a, 'g> { /* private fields */ }Expand description
A terminal node represents the end of a game
Terminal nodes simply assign payoffs to every player in the game
Implementations
Sourceimpl<'a, 'g> Terminal<'a, 'g>
impl<'a, 'g> Terminal<'a, 'g>
Sourcepub fn name(self) -> &'a EscapedStr
pub fn name(self) -> &'a EscapedStr
The name of this node
Sourcepub fn outcome_name(self) -> Option<&'a EscapedStr>
pub fn outcome_name(self) -> Option<&'a EscapedStr>
The name of this outcome
None for the null (0) outcome or an outcome with no name.
Sourcepub fn outcome_payoffs(self) -> Option<&'g [BigRational]>
pub fn outcome_payoffs(self) -> Option<&'g [BigRational]>
The payoffs to every player
None only for the null (0) outcome — a terminal with no outcome attached.