#[non_exhaustive]pub enum ValidationError {
ChanceNotDistribution,
InvalidPlayerNum,
NonMatchingInfosetNames,
NonMatchingInfosetActions,
NullOutcomePayoffs,
InvalidNumberOfPayoffs,
NonMatchingOutcomeNames,
NonMatchingOutcomePayoffs,
NoOutcomePayoffs,
UndeclaredInfoset,
}Expand description
An error that results from something invalid about the parsed extensive form game
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ChanceNotDistribution
The probabilities of actions associated with a chance node don’t sum to one
InvalidPlayerNum
A player’s number wasn’t between one and the number of players
NonMatchingInfosetNames
An infoset had different names attached to it
NonMatchingInfosetActions
An infoset had different sets of associated actions
NullOutcomePayoffs
There was payoff data associated with the null (0) outcome
InvalidNumberOfPayoffs
The number of specified payoffs did not match the number of players
NonMatchingOutcomeNames
An outcome had different names attached to it
NonMatchingOutcomePayoffs
An outcome had different associated payoffs
NoOutcomePayoffs
An outcome was defined without payoffs
UndeclaredInfoset
A node omitted its action list for an infoset that was never declared