Chance

Struct Chance 

pub struct Chance<'a, 'g> { /* private fields */ }
A chance node

A chance node represents a point in the game where things advance randomly, or alternatively, where “nature” takes a turn.

Implementations

Source

impl<'a, 'g> Chance<'a, 'g>

pub fn name(self) -> &'a EscapedStr

The name of the node

pub fn infoset(self) -> u64

The id of the node’s infoset

pub fn infoset_name(self) -> &'a EscapedStr

The infoset’s label

pub fn actions( self, ) -> impl Iterator<Item = (&'a EscapedStr, &'g BigRational, Node<'a, 'g>)> + 'g

All possible actions with their names, probabilities, and resulting nodes

pub fn action( self, label: &EscapedStr, ) -> Option<(&'g BigRational, Node<'a, 'g>)>

The probability and child for the action with the given label

Labels need not be unique within an infoset, so this returns the first match.

pub fn len(self) -> usize

The number of actions (always at least one)

pub fn action_at( self, index: usize, ) -> Option<(&'a EscapedStr, &'g BigRational, Node<'a, 'g>)>

The name, probability, and child for the action at the given index

pub fn outcome(self) -> u64

The outcome id

pub fn outcome_name(self) -> Option<&'a EscapedStr>

The name of the outcome

None for the null (0) outcome or an outcome with no name.

pub fn outcome_payoffs(self) -> Option<&'g [BigRational]>

Outcome payoffs for this node

These are added to every player’s payoff for traversing through this node. None only for the null (0) outcome.